import PySide2.QtCore
import _typeshed
import collections.abc
import datetime
import shiboken2
import typing
T = typing.TypeVar('T')
import typing_extensions

class QScriptClass(shiboken2.Object):
    class Extension:
        Callable: typing.ClassVar[QScriptClass.Extension] = ...
        HasInstance: typing.ClassVar[QScriptClass.Extension] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __sub__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptClass.Extension: ...

    class QueryFlag:
        HandlesReadAccess: typing.ClassVar[QScriptClass.QueryFlag] = ...
        HandlesWriteAccess: typing.ClassVar[QScriptClass.QueryFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __sub__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptClass.QueryFlag: ...
    Callable: typing.ClassVar[QScriptClass.Extension] = ...
    HandlesReadAccess: typing.ClassVar[QScriptClass.QueryFlag] = ...
    HandlesWriteAccess: typing.ClassVar[QScriptClass.QueryFlag] = ...
    HasInstance: typing.ClassVar[QScriptClass.Extension] = ...
    def __init__(self, engine: QScriptEngine) -> None: ...
    def engine(self) -> QScriptEngine: ...
    def extension(self, extension: QScriptClass.Extension, argument: typing.Any = ...) -> typing.Any: ...
    def name(self) -> str: ...
    def newIterator(self, object: QScriptValue) -> QScriptClassPropertyIterator: ...
    def property(self, object: QScriptValue, name: QScriptString, id: int) -> QScriptValue: ...
    def propertyFlags(self, object: QScriptValue, name: QScriptString, id: int) -> typing.Union[QScriptValue.PropertyFlags, QScriptValue.PropertyFlag]: ...
    def prototype(self) -> QScriptValue: ...
    def setProperty(self, object: QScriptValue, name: QScriptString, id: int, value: QScriptValue) -> None: ...
    def supportsExtension(self, extension: QScriptClass.Extension) -> bool: ...

class QScriptClassPropertyIterator(shiboken2.Object):
    def __init__(self, object: QScriptValue) -> None: ...
    def flags(self) -> typing.Union[QScriptValue.PropertyFlags, QScriptValue.PropertyFlag]: ...
    def hasNext(self) -> bool: ...
    def hasPrevious(self) -> bool: ...
    def id(self) -> int: ...
    def name(self) -> QScriptString: ...
    def next(self) -> None: ...
    def object(self) -> QScriptValue: ...
    def previous(self) -> None: ...
    def toBack(self) -> None: ...
    def toFront(self) -> None: ...

class QScriptContext(shiboken2.Object):
    class Error:
        RangeError: typing.ClassVar[QScriptContext.Error] = ...
        ReferenceError: typing.ClassVar[QScriptContext.Error] = ...
        SyntaxError: typing.ClassVar[QScriptContext.Error] = ...
        TypeError: typing.ClassVar[QScriptContext.Error] = ...
        URIError: typing.ClassVar[QScriptContext.Error] = ...
        UnknownError: typing.ClassVar[QScriptContext.Error] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __sub__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptContext.Error: ...

    class ExecutionState:
        ExceptionState: typing.ClassVar[QScriptContext.ExecutionState] = ...
        NormalState: typing.ClassVar[QScriptContext.ExecutionState] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __sub__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptContext.ExecutionState: ...
    ExceptionState: typing.ClassVar[QScriptContext.ExecutionState] = ...
    NormalState: typing.ClassVar[QScriptContext.ExecutionState] = ...
    RangeError: typing.ClassVar[QScriptContext.Error] = ...
    ReferenceError: typing.ClassVar[QScriptContext.Error] = ...
    SyntaxError: typing.ClassVar[QScriptContext.Error] = ...
    TypeError: typing.ClassVar[QScriptContext.Error] = ...
    URIError: typing.ClassVar[QScriptContext.Error] = ...
    UnknownError: typing.ClassVar[QScriptContext.Error] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    def activationObject(self) -> QScriptValue: ...
    def argument(self, index: int) -> QScriptValue: ...
    def argumentCount(self) -> int: ...
    def argumentsObject(self) -> QScriptValue: ...
    def backtrace(self) -> typing.List[str]: ...
    def callee(self) -> QScriptValue: ...
    def engine(self) -> QScriptEngine: ...
    def isCalledAsConstructor(self) -> bool: ...
    def parentContext(self) -> QScriptContext: ...
    def popScope(self) -> QScriptValue: ...
    def pushScope(self, object: QScriptValue) -> None: ...
    def returnValue(self) -> QScriptValue: ...
    def scopeChain(self) -> typing.List[QScriptValue]: ...
    def setActivationObject(self, activation: QScriptValue) -> None: ...
    def setReturnValue(self, result: QScriptValue) -> None: ...
    def setThisObject(self, thisObject: QScriptValue) -> None: ...
    def state(self) -> QScriptContext.ExecutionState: ...
    def thisObject(self) -> QScriptValue: ...
    @typing.overload
    def throwError(self, error: QScriptContext.Error, text: str) -> QScriptValue: ...
    @typing.overload
    def throwError(self, text: str) -> QScriptValue: ...
    def throwValue(self, value: QScriptValue) -> QScriptValue: ...
    def toString(self) -> str: ...

class QScriptContextInfo(shiboken2.Object):
    class FunctionType:
        NativeFunction: typing.ClassVar[QScriptContextInfo.FunctionType] = ...
        QtFunction: typing.ClassVar[QScriptContextInfo.FunctionType] = ...
        QtPropertyFunction: typing.ClassVar[QScriptContextInfo.FunctionType] = ...
        ScriptFunction: typing.ClassVar[QScriptContextInfo.FunctionType] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __sub__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptContextInfo.FunctionType: ...
    NativeFunction: typing.ClassVar[QScriptContextInfo.FunctionType] = ...
    QtFunction: typing.ClassVar[QScriptContextInfo.FunctionType] = ...
    QtPropertyFunction: typing.ClassVar[QScriptContextInfo.FunctionType] = ...
    ScriptFunction: typing.ClassVar[QScriptContextInfo.FunctionType] = ...
    @typing.overload
    def __init__(self, other: QScriptContextInfo) -> None: ...
    @typing.overload
    def __init__(self, context: QScriptContext) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    def columnNumber(self) -> int: ...
    def fileName(self) -> str: ...
    def functionEndLineNumber(self) -> int: ...
    def functionMetaIndex(self) -> int: ...
    def functionName(self) -> str: ...
    def functionParameterNames(self) -> typing.List[str]: ...
    def functionStartLineNumber(self) -> int: ...
    def functionType(self) -> QScriptContextInfo.FunctionType: ...
    def isNull(self) -> bool: ...
    def lineNumber(self) -> int: ...
    def scriptId(self) -> int: ...
    def __bool__(self) -> bool: ...
    def __copy__(self) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lshift__(self, arg__1: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __rlshift__(self, other): ...
    def __rrshift__(self, other): ...
    def __rshift__(self, arg__1: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...

class QScriptEngine(PySide2.QtCore.QObject):
    class QObjectWrapOption:
        AutoCreateDynamicProperties: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
        ExcludeChildObjects: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
        ExcludeDeleteLater: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
        ExcludeSlots: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
        ExcludeSuperClassContents: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
        ExcludeSuperClassMethods: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
        ExcludeSuperClassProperties: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
        PreferExistingWrapperObject: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
        SkipMethodsInEnumeration: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QScriptEngine.QObjectWrapOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...

    class QObjectWrapOptions:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QScriptEngine.QObjectWrapOptions: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptEngine.QObjectWrapOptions: ...

    class ValueOwnership:
        AutoOwnership: typing.ClassVar[QScriptEngine.ValueOwnership] = ...
        QtOwnership: typing.ClassVar[QScriptEngine.ValueOwnership] = ...
        ScriptOwnership: typing.ClassVar[QScriptEngine.ValueOwnership] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __sub__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptEngine.ValueOwnership: ...
    AutoCreateDynamicProperties: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
    AutoOwnership: typing.ClassVar[QScriptEngine.ValueOwnership] = ...
    ExcludeChildObjects: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
    ExcludeDeleteLater: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
    ExcludeSlots: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
    ExcludeSuperClassContents: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
    ExcludeSuperClassMethods: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
    ExcludeSuperClassProperties: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
    PreferExistingWrapperObject: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
    QtOwnership: typing.ClassVar[QScriptEngine.ValueOwnership] = ...
    ScriptOwnership: typing.ClassVar[QScriptEngine.ValueOwnership] = ...
    SkipMethodsInEnumeration: typing.ClassVar[QScriptEngine.QObjectWrapOption] = ...
    signalHandlerException: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None], destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., signalHandlerException: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., signalHandlerException: typing.Callable = ...) -> None: ...
    def abortEvaluation(self, result: QScriptValue = ...) -> None: ...
    def agent(self) -> QScriptEngineAgent: ...
    def availableExtensions(self) -> typing.List[str]: ...
    def canEvaluate(self, program: str) -> bool: ...
    def clearExceptions(self) -> None: ...
    def collectGarbage(self) -> None: ...
    def currentContext(self) -> QScriptContext: ...
    def defaultPrototype(self, metaTypeId: int) -> QScriptValue: ...
    @typing.overload
    def evaluate(self, program: str, fileName: str = ..., lineNumber: int = ...) -> QScriptValue: ...
    @typing.overload
    def evaluate(self, program: QScriptProgram) -> QScriptValue: ...
    def globalObject(self) -> QScriptValue: ...
    def hasUncaughtException(self) -> bool: ...
    def importExtension(self, extension: str) -> QScriptValue: ...
    def importedExtensions(self) -> typing.List[str]: ...
    def installTranslatorFunctions(self, object: QScriptValue = ...) -> None: ...
    def isEvaluating(self) -> bool: ...
    def newActivationObject(self) -> QScriptValue: ...
    def newArray(self, length: int = ...) -> QScriptValue: ...
    @typing.overload
    def newDate(self, value: typing.Union[PySide2.QtCore.QDateTime, datetime.datetime]) -> QScriptValue: ...
    @typing.overload
    def newDate(self, value: float) -> QScriptValue: ...
    @typing.overload
    def newObject(self, scriptClass: QScriptClass, data: QScriptValue = ...) -> QScriptValue: ...
    @typing.overload
    def newObject(self) -> QScriptValue: ...
    def newQMetaObject(self, metaObject: PySide2.QtCore.QMetaObject, ctor: QScriptValue = ...) -> QScriptValue: ...
    @typing.overload
    def newQObject(self, scriptObject: QScriptValue, qtObject: PySide2.QtCore.QObject, ownership: QScriptEngine.ValueOwnership = ..., options: typing.Union[QScriptEngine.QObjectWrapOptions, QScriptEngine.QObjectWrapOption] = ...) -> QScriptValue: ...
    @typing.overload
    def newQObject(self, object: PySide2.QtCore.QObject, ownership: QScriptEngine.ValueOwnership = ..., options: typing.Union[QScriptEngine.QObjectWrapOptions, QScriptEngine.QObjectWrapOption] = ...) -> QScriptValue: ...
    @typing.overload
    def newRegExp(self, pattern: str, flags: str) -> QScriptValue: ...
    @typing.overload
    def newRegExp(self, regexp: PySide2.QtCore.QRegExp) -> QScriptValue: ...
    @typing.overload
    def newVariant(self, object: QScriptValue, value: typing.Any) -> QScriptValue: ...
    @typing.overload
    def newVariant(self, value: typing.Any) -> QScriptValue: ...
    def nullValue(self) -> QScriptValue: ...
    def objectById(self, id: int) -> QScriptValue: ...
    def popContext(self) -> None: ...
    def processEventsInterval(self) -> int: ...
    def pushContext(self) -> QScriptContext: ...
    def reportAdditionalMemoryCost(self, size: int) -> None: ...
    def setAgent(self, agent: QScriptEngineAgent) -> None: ...
    def setDefaultPrototype(self, metaTypeId: int, prototype: QScriptValue) -> None: ...
    def setGlobalObject(self, object: QScriptValue) -> None: ...
    def setProcessEventsInterval(self, interval: int) -> None: ...
    def toObject(self, value: QScriptValue) -> QScriptValue: ...
    def toStringHandle(self, str: str) -> QScriptString: ...
    def uncaughtException(self) -> QScriptValue: ...
    def uncaughtExceptionBacktrace(self) -> typing.List[str]: ...
    def uncaughtExceptionLineNumber(self) -> int: ...
    def undefinedValue(self) -> QScriptValue: ...

class QScriptEngineAgent(shiboken2.Object):
    class Extension:
        DebuggerInvocationRequest: typing.ClassVar[QScriptEngineAgent.Extension] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __sub__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptEngineAgent.Extension: ...
    DebuggerInvocationRequest: typing.ClassVar[QScriptEngineAgent.Extension] = ...
    def __init__(self, engine: QScriptEngine) -> None: ...
    def contextPop(self) -> None: ...
    def contextPush(self) -> None: ...
    def engine(self) -> QScriptEngine: ...
    def exceptionCatch(self, scriptId: int, exception: QScriptValue) -> None: ...
    def exceptionThrow(self, scriptId: int, exception: QScriptValue, hasHandler: bool) -> None: ...
    def extension(self, extension: QScriptEngineAgent.Extension, argument: typing.Any = ...) -> typing.Any: ...
    def functionEntry(self, scriptId: int) -> None: ...
    def functionExit(self, scriptId: int, returnValue: QScriptValue) -> None: ...
    def positionChange(self, scriptId: int, lineNumber: int, columnNumber: int) -> None: ...
    def scriptLoad(self, id: int, program: str, fileName: str, baseLineNumber: int) -> None: ...
    def scriptUnload(self, id: int) -> None: ...
    def supportsExtension(self, extension: QScriptEngineAgent.Extension) -> bool: ...

class QScriptExtensionInterface(PySide2.QtCore.QFactoryInterface):
    def __init__(self) -> None: ...
    def initialize(self, key: str, engine: QScriptEngine) -> None: ...

class QScriptExtensionPlugin(PySide2.QtCore.QObject, QScriptExtensionInterface):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def initialize(self, key: str, engine: QScriptEngine) -> None: ...
    def keys(self) -> typing.List[str]: ...
    def setupPackage(self, key: str, engine: QScriptEngine) -> QScriptValue: ...

class QScriptProgram(shiboken2.Object):
    @typing.overload
    def __init__(self, sourceCode: str, fileName: str = ..., firstLineNumber: int = ...) -> None: ...
    @typing.overload
    def __init__(self, other: QScriptProgram) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    def fileName(self) -> str: ...
    def firstLineNumber(self) -> int: ...
    def isNull(self) -> bool: ...
    def sourceCode(self) -> str: ...
    def __bool__(self) -> bool: ...
    def __copy__(self) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class QScriptString(shiboken2.Object):
    @typing.overload
    def __init__(self, other: QScriptString) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    def isValid(self) -> bool: ...
    def toArrayIndex(self) -> typing.Tuple[int, bool]: ...
    def toString(self) -> str: ...
    def __copy__(self) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class QScriptValue(shiboken2.Object):
    class PropertyFlag:
        KeepExistingFlags: typing.ClassVar[QScriptValue.PropertyFlag] = ...
        PropertyGetter: typing.ClassVar[QScriptValue.PropertyFlag] = ...
        PropertySetter: typing.ClassVar[QScriptValue.PropertyFlag] = ...
        QObjectMember: typing.ClassVar[QScriptValue.PropertyFlag] = ...
        ReadOnly: typing.ClassVar[QScriptValue.PropertyFlag] = ...
        SkipInEnumeration: typing.ClassVar[QScriptValue.PropertyFlag] = ...
        Undeletable: typing.ClassVar[QScriptValue.PropertyFlag] = ...
        UserRange: typing.ClassVar[QScriptValue.PropertyFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QScriptValue.PropertyFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...

    class PropertyFlags:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QScriptValue.PropertyFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptValue.PropertyFlags: ...

    class ResolveFlag:
        ResolveFull: typing.ClassVar[QScriptValue.ResolveFlag] = ...
        ResolveLocal: typing.ClassVar[QScriptValue.ResolveFlag] = ...
        ResolvePrototype: typing.ClassVar[QScriptValue.ResolveFlag] = ...
        ResolveScope: typing.ClassVar[QScriptValue.ResolveFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QScriptValue.ResolveFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...

    class ResolveFlags:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> QScriptValue.ResolveFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptValue.ResolveFlags: ...

    class SpecialValue:
        NullValue: typing.ClassVar[QScriptValue.SpecialValue] = ...
        UndefinedValue: typing.ClassVar[QScriptValue.SpecialValue] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __and__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __rand__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __rmul__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __ror__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __rsub__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __rxor__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __sub__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
        def __xor__(self, other: typing.SupportsInt) -> QScriptValue.SpecialValue: ...
    KeepExistingFlags: typing.ClassVar[QScriptValue.PropertyFlag] = ...
    NullValue: typing.ClassVar[QScriptValue.SpecialValue] = ...
    PropertyGetter: typing.ClassVar[QScriptValue.PropertyFlag] = ...
    PropertySetter: typing.ClassVar[QScriptValue.PropertyFlag] = ...
    QObjectMember: typing.ClassVar[QScriptValue.PropertyFlag] = ...
    ReadOnly: typing.ClassVar[QScriptValue.PropertyFlag] = ...
    ResolveFull: typing.ClassVar[QScriptValue.ResolveFlag] = ...
    ResolveLocal: typing.ClassVar[QScriptValue.ResolveFlag] = ...
    ResolvePrototype: typing.ClassVar[QScriptValue.ResolveFlag] = ...
    ResolveScope: typing.ClassVar[QScriptValue.ResolveFlag] = ...
    SkipInEnumeration: typing.ClassVar[QScriptValue.PropertyFlag] = ...
    UndefinedValue: typing.ClassVar[QScriptValue.SpecialValue] = ...
    Undeletable: typing.ClassVar[QScriptValue.PropertyFlag] = ...
    UserRange: typing.ClassVar[QScriptValue.PropertyFlag] = ...
    @typing.overload
    def __init__(self, engine: QScriptEngine, val: QScriptValue.SpecialValue) -> None: ...
    @typing.overload
    def __init__(self, engine: QScriptEngine, val: str) -> None: ...
    @typing.overload
    def __init__(self, engine: QScriptEngine, val: bool) -> None: ...
    @typing.overload
    def __init__(self, engine: QScriptEngine, val: bytes) -> None: ...
    @typing.overload
    def __init__(self, engine: QScriptEngine, val: float) -> None: ...
    @typing.overload
    def __init__(self, engine: QScriptEngine, val: int) -> None: ...
    @typing.overload
    def __init__(self, value: QScriptValue.SpecialValue) -> None: ...
    @typing.overload
    def __init__(self, value: str) -> None: ...
    @typing.overload
    def __init__(self, value: bool) -> None: ...
    @typing.overload
    def __init__(self, value: bytes) -> None: ...
    @typing.overload
    def __init__(self, value: float) -> None: ...
    @typing.overload
    def __init__(self, value: int) -> None: ...
    @typing.overload
    def __init__(self, other: QScriptValue) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def call(self, thisObject: QScriptValue, arguments: QScriptValue) -> QScriptValue: ...
    @typing.overload
    def call(self, thisObject: QScriptValue = ..., args: typing.Iterable[QScriptValue] = ...) -> QScriptValue: ...
    @typing.overload
    def construct(self, arguments: QScriptValue) -> QScriptValue: ...
    @typing.overload
    def construct(self, args: typing.Iterable[QScriptValue] = ...) -> QScriptValue: ...
    def data(self) -> QScriptValue: ...
    def engine(self) -> QScriptEngine: ...
    def equals(self, other: QScriptValue) -> bool: ...
    def instanceOf(self, other: QScriptValue) -> bool: ...
    def isArray(self) -> bool: ...
    def isBool(self) -> bool: ...
    def isBoolean(self) -> bool: ...
    def isDate(self) -> bool: ...
    def isError(self) -> bool: ...
    def isFunction(self) -> bool: ...
    def isNull(self) -> bool: ...
    def isNumber(self) -> bool: ...
    def isObject(self) -> bool: ...
    def isQMetaObject(self) -> bool: ...
    def isQObject(self) -> bool: ...
    def isRegExp(self) -> bool: ...
    def isString(self) -> bool: ...
    def isUndefined(self) -> bool: ...
    def isValid(self) -> bool: ...
    def isVariant(self) -> bool: ...
    def lessThan(self, other: QScriptValue) -> bool: ...
    def objectId(self) -> int: ...
    @typing.overload
    def property(self, name: QScriptString, mode: typing.Union[QScriptValue.ResolveFlags, QScriptValue.ResolveFlag] = ...) -> QScriptValue: ...
    @typing.overload
    def property(self, name: str, mode: typing.Union[QScriptValue.ResolveFlags, QScriptValue.ResolveFlag] = ...) -> QScriptValue: ...
    @typing.overload
    def property(self, arrayIndex: int, mode: typing.Union[QScriptValue.ResolveFlags, QScriptValue.ResolveFlag] = ...) -> QScriptValue: ...
    @typing.overload
    def propertyFlags(self, name: QScriptString, mode: typing.Union[QScriptValue.ResolveFlags, QScriptValue.ResolveFlag] = ...) -> typing.Union[QScriptValue.PropertyFlags, QScriptValue.PropertyFlag]: ...
    @typing.overload
    def propertyFlags(self, name: str, mode: typing.Union[QScriptValue.ResolveFlags, QScriptValue.ResolveFlag] = ...) -> typing.Union[QScriptValue.PropertyFlags, QScriptValue.PropertyFlag]: ...
    def prototype(self) -> QScriptValue: ...
    def scope(self) -> QScriptValue: ...
    def scriptClass(self) -> QScriptClass: ...
    def setData(self, data: QScriptValue) -> None: ...
    @typing.overload
    def setProperty(self, name: QScriptString, value: QScriptValue, flags: typing.Union[QScriptValue.PropertyFlags, QScriptValue.PropertyFlag] = ...) -> None: ...
    @typing.overload
    def setProperty(self, name: str, value: QScriptValue, flags: typing.Union[QScriptValue.PropertyFlags, QScriptValue.PropertyFlag] = ...) -> None: ...
    @typing.overload
    def setProperty(self, arrayIndex: int, value: QScriptValue, flags: typing.Union[QScriptValue.PropertyFlags, QScriptValue.PropertyFlag] = ...) -> None: ...
    def setPrototype(self, prototype: QScriptValue) -> None: ...
    def setScope(self, scope: QScriptValue) -> None: ...
    def setScriptClass(self, scriptClass: QScriptClass) -> None: ...
    def strictlyEquals(self, other: QScriptValue) -> bool: ...
    def toBool(self) -> bool: ...
    def toBoolean(self) -> bool: ...
    def toDateTime(self) -> PySide2.QtCore.QDateTime: ...
    def toInt32(self) -> int: ...
    def toInteger(self) -> float: ...
    def toNumber(self) -> float: ...
    def toObject(self) -> QScriptValue: ...
    def toQMetaObject(self) -> PySide2.QtCore.QMetaObject: ...
    def toQObject(self) -> PySide2.QtCore.QObject: ...
    def toRegExp(self) -> PySide2.QtCore.QRegExp: ...
    def toString(self) -> str: ...
    def toUInt16(self) -> int: ...
    def toUInt32(self) -> int: ...
    def toVariant(self) -> typing.Any: ...
    def __bool__(self) -> bool: ...
    def __copy__(self) -> None: ...
    def __getitem__(self, index): ...
    def __iter__(self) -> object: ...

class QScriptValueIterator(shiboken2.Object):
    def __init__(self, value: QScriptValue) -> None: ...
    def flags(self) -> typing.Union[QScriptValue.PropertyFlags, QScriptValue.PropertyFlag]: ...
    def hasNext(self) -> bool: ...
    def hasPrevious(self) -> bool: ...
    def name(self) -> str: ...
    def next(self) -> None: ...
    def previous(self) -> None: ...
    def remove(self) -> None: ...
    def scriptName(self) -> QScriptString: ...
    def setValue(self, value: QScriptValue) -> None: ...
    def toBack(self) -> None: ...
    def toFront(self) -> None: ...
    def value(self) -> QScriptValue: ...
    def __iter__(self) -> object: ...
    def __next__(self) -> object: ...

class QScriptable(shiboken2.Object):
    def __init__(self) -> None: ...
    def argument(self, index: int) -> QScriptValue: ...
    def argumentCount(self) -> int: ...
    def context(self) -> QScriptContext: ...
    def engine(self) -> QScriptEngine: ...
    def thisObject(self) -> QScriptValue: ...



import PySide2.Qt3DCore
import PySide2.QtCore
import PySide2.QtGui
import _typeshed
import collections.abc
import shiboken2
import typing
T = typing.TypeVar('T')
import typing_extensions

class Qt3DInput(shiboken2.Object):
    class QAbstractActionInput(PySide2.Qt3DCore.Qt3DCore.QNode):
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...

    class QAbstractAxisInput(PySide2.Qt3DCore.Qt3DCore.QNode):
        sourceDeviceChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def setSourceDevice(self, sourceDevice: Qt3DInput.QAbstractPhysicalDevice) -> None: ...
        def sourceDevice(self) -> Qt3DInput.QAbstractPhysicalDevice: ...

    class QAbstractPhysicalDevice(PySide2.Qt3DCore.Qt3DCore.QNode):
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., defaultPropertyTrackingMode: Qt3DInput.QAbstractPhysicalDevice.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ...) -> None: ...
        def addAxisSetting(self, axisSetting: Qt3DInput.QAxisSetting) -> None: ...
        def axisCount(self) -> int: ...
        def axisIdentifier(self, name: str) -> int: ...
        def axisNames(self) -> typing.List[str]: ...
        def axisSettings(self) -> typing.List[Qt3DInput.QAxisSetting]: ...
        def buttonCount(self) -> int: ...
        def buttonIdentifier(self, name: str) -> int: ...
        def buttonNames(self) -> typing.List[str]: ...
        def removeAxisSetting(self, axisSetting: Qt3DInput.QAxisSetting) -> None: ...

    class QAction(PySide2.Qt3DCore.Qt3DCore.QNode):
        activeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., active: bool = ..., activeChanged: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QAction.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ...) -> None: ...
        def addInput(self, input: Qt3DInput.QAbstractActionInput) -> None: ...
        def inputs(self) -> typing.List[Qt3DInput.QAbstractActionInput]: ...
        def isActive(self) -> bool: ...
        def removeInput(self, input: Qt3DInput.QAbstractActionInput) -> None: ...

    class QActionInput(Qt3DInput.QAbstractActionInput):
        buttonsChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        sourceDeviceChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., buttons: typing.List[int] = ..., buttonsChanged: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QActionInput.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., sourceDevice: Qt3DInput.QAbstractPhysicalDevice = ..., sourceDeviceChanged: typing.Callable = ...) -> None: ...
        def buttons(self) -> typing.List[int]: ...
        def setButtons(self, buttons: typing.List[int]) -> None: ...
        def setSourceDevice(self, sourceDevice: Qt3DInput.QAbstractPhysicalDevice) -> None: ...
        def sourceDevice(self) -> Qt3DInput.QAbstractPhysicalDevice: ...

    class QAnalogAxisInput(Qt3DInput.QAbstractAxisInput):
        axisChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., axis: int = ..., axisChanged: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QAnalogAxisInput.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., sourceDevice: typing.Any = ..., sourceDeviceChanged: typing.Callable = ...) -> None: ...
        def axis(self) -> int: ...
        def setAxis(self, axis: int) -> None: ...

    class QAxis(PySide2.Qt3DCore.Qt3DCore.QNode):
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        valueChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., defaultPropertyTrackingMode: Qt3DInput.QAxis.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., value: float = ..., valueChanged: typing.Callable = ...) -> None: ...
        def addInput(self, input: Qt3DInput.QAbstractAxisInput) -> None: ...
        def inputs(self) -> typing.List[Qt3DInput.QAbstractAxisInput]: ...
        def removeInput(self, input: Qt3DInput.QAbstractAxisInput) -> None: ...
        def value(self) -> float: ...

    class QAxisAccumulator(PySide2.Qt3DCore.Qt3DCore.QComponent):
        class SourceAxisType:
            Acceleration: typing.ClassVar[Qt3DInput.QAxisAccumulator.SourceAxisType] = ...
            Velocity: typing.ClassVar[Qt3DInput.QAxisAccumulator.SourceAxisType] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __add__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __mul__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __pos__(self): ...
            def __radd__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __rmul__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __rsub__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __sub__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
        Acceleration: typing.ClassVar[Qt3DInput.QAxisAccumulator.SourceAxisType] = ...
        Velocity: typing.ClassVar[Qt3DInput.QAxisAccumulator.SourceAxisType] = ...
        scaleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        sourceAxisChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        sourceAxisTypeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        valueChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        velocityChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., addedToEntity: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QAxisAccumulator.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., isShareable: bool = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., removedFromEntity: typing.Callable = ..., scale: float = ..., scaleChanged: typing.Callable = ..., shareableChanged: typing.Callable = ..., sourceAxis: Qt3DInput.QAxis = ..., sourceAxisChanged: typing.Callable = ..., sourceAxisType: Qt3DInput.QAxisAccumulator.SourceAxisType = ..., sourceAxisTypeChanged: typing.Callable = ..., value: float = ..., valueChanged: typing.Callable = ..., velocity: float = ..., velocityChanged: typing.Callable = ...) -> None: ...
        def scale(self) -> float: ...
        def setScale(self, scale: float) -> None: ...
        def setSourceAxis(self, sourceAxis: Qt3DInput.QAxis) -> None: ...
        def setSourceAxisType(self, sourceAxisType: Qt3DInput.QAxisAccumulator.SourceAxisType) -> None: ...
        def sourceAxis(self) -> Qt3DInput.QAxis: ...
        def sourceAxisType(self) -> Qt3DInput.QAxisAccumulator.SourceAxisType: ...
        def value(self) -> float: ...
        def velocity(self) -> float: ...

    class QAxisSetting(PySide2.Qt3DCore.Qt3DCore.QNode):
        axesChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        deadZoneRadiusChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        smoothChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., axes: typing.List[int] = ..., axesChanged: typing.Callable = ..., deadZoneRadius: float = ..., deadZoneRadiusChanged: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QAxisSetting.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., smooth: bool = ..., smoothChanged: typing.Callable = ...) -> None: ...
        def axes(self) -> typing.List[int]: ...
        def deadZoneRadius(self) -> float: ...
        def isSmoothEnabled(self) -> bool: ...
        def setAxes(self, axes: typing.List[int]) -> None: ...
        def setDeadZoneRadius(self, deadZoneRadius: float) -> None: ...
        def setSmoothEnabled(self, enabled: bool) -> None: ...

    class QButtonAxisInput(Qt3DInput.QAbstractAxisInput):
        accelerationChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        buttonsChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        decelerationChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        scaleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., acceleration: float = ..., accelerationChanged: typing.Callable = ..., buttons: typing.List[int] = ..., buttonsChanged: typing.Callable = ..., deceleration: float = ..., decelerationChanged: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QButtonAxisInput.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., scale: float = ..., scaleChanged: typing.Callable = ..., sourceDevice: typing.Any = ..., sourceDeviceChanged: typing.Callable = ...) -> None: ...
        def acceleration(self) -> float: ...
        def buttons(self) -> typing.List[int]: ...
        def deceleration(self) -> float: ...
        def scale(self) -> float: ...
        def setAcceleration(self, acceleration: float) -> None: ...
        def setButtons(self, buttons: typing.List[int]) -> None: ...
        def setDeceleration(self, deceleration: float) -> None: ...
        def setScale(self, scale: float) -> None: ...

    class QInputAspect(PySide2.Qt3DCore.Qt3DCore.QAbstractAspect):
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
        def availablePhysicalDevices(self) -> typing.List[str]: ...
        def createPhysicalDevice(self, name: str) -> Qt3DInput.QAbstractPhysicalDevice: ...

    class QInputChord(Qt3DInput.QAbstractActionInput):
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        timeoutChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., defaultPropertyTrackingMode: Qt3DInput.QInputChord.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., timeout: int = ..., timeoutChanged: typing.Callable = ...) -> None: ...
        def addChord(self, input: Qt3DInput.QAbstractActionInput) -> None: ...
        def chords(self) -> typing.List[Qt3DInput.QAbstractActionInput]: ...
        def removeChord(self, input: Qt3DInput.QAbstractActionInput) -> None: ...
        def setTimeout(self, timeout: int) -> None: ...
        def timeout(self) -> int: ...

    class QInputSequence(Qt3DInput.QAbstractActionInput):
        buttonIntervalChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        timeoutChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., buttonInterval: int = ..., buttonIntervalChanged: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QInputSequence.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., timeout: int = ..., timeoutChanged: typing.Callable = ...) -> None: ...
        def addSequence(self, input: Qt3DInput.QAbstractActionInput) -> None: ...
        def buttonInterval(self) -> int: ...
        def removeSequence(self, input: Qt3DInput.QAbstractActionInput) -> None: ...
        def sequences(self) -> typing.List[Qt3DInput.QAbstractActionInput]: ...
        def setButtonInterval(self, buttonInterval: int) -> None: ...
        def setTimeout(self, timeout: int) -> None: ...
        def timeout(self) -> int: ...

    class QInputSettings(PySide2.Qt3DCore.Qt3DCore.QComponent):
        eventSourceChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., addedToEntity: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QInputSettings.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., eventSource: PySide2.QtCore.QObject = ..., eventSourceChanged: typing.Callable = ..., isShareable: bool = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., removedFromEntity: typing.Callable = ..., shareableChanged: typing.Callable = ...) -> None: ...
        def eventSource(self) -> PySide2.QtCore.QObject: ...
        def setEventSource(self, eventSource: PySide2.QtCore.QObject) -> None: ...

    class QKeyEvent(PySide2.QtCore.QObject):
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, type: PySide2.QtCore.QEvent.Type, key: int, modifiers: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier], text: str = ..., autorep: bool = ..., count: int = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
        def count(self) -> int: ...
        def isAccepted(self) -> bool: ...
        def isAutoRepeat(self) -> bool: ...
        def key(self) -> int: ...
        def matches(self, key_: PySide2.QtGui.QKeySequence.StandardKey) -> bool: ...
        def modifiers(self) -> int: ...
        def nativeScanCode(self) -> int: ...
        def setAccepted(self, accepted: bool) -> None: ...
        def text(self) -> str: ...
        def type(self) -> PySide2.QtCore.QEvent.Type: ...

    class QKeyboardDevice(Qt3DInput.QAbstractPhysicalDevice):
        activeInputChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., activeInput: Qt3DInput.QKeyboardHandler = ..., activeInputChanged: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QKeyboardDevice.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ...) -> None: ...
        def activeInput(self) -> Qt3DInput.QKeyboardHandler: ...
        def axisCount(self) -> int: ...
        def axisIdentifier(self, name: str) -> int: ...
        def axisNames(self) -> typing.List[str]: ...
        def buttonCount(self) -> int: ...
        def buttonIdentifier(self, name: str) -> int: ...
        def buttonNames(self) -> typing.List[str]: ...

    class QKeyboardHandler(PySide2.Qt3DCore.Qt3DCore.QComponent):
        asteriskPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        backPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        backtabPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        callPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        cancelPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        context1Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        context2Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        context3Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        context4Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        deletePressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        digit0Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        digit1Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        digit2Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        digit3Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        digit4Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        digit5Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        digit6Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        digit7Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        digit8Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        digit9Pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        downPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        enterPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        escapePressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        flipPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        focusChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        hangupPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        leftPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        menuPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        noPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        numberSignPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        released: typing.ClassVar[PySide2.QtCore.Signal] = ...
        returnPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        rightPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        selectPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        sourceDeviceChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        spacePressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        tabPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        upPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        volumeDownPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        volumeUpPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        yesPressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., addedToEntity: typing.Callable = ..., asteriskPressed: typing.Callable = ..., backPressed: typing.Callable = ..., backtabPressed: typing.Callable = ..., callPressed: typing.Callable = ..., cancelPressed: typing.Callable = ..., context1Pressed: typing.Callable = ..., context2Pressed: typing.Callable = ..., context3Pressed: typing.Callable = ..., context4Pressed: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QKeyboardHandler.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., deletePressed: typing.Callable = ..., destroyed: typing.Callable = ..., digit0Pressed: typing.Callable = ..., digit1Pressed: typing.Callable = ..., digit2Pressed: typing.Callable = ..., digit3Pressed: typing.Callable = ..., digit4Pressed: typing.Callable = ..., digit5Pressed: typing.Callable = ..., digit6Pressed: typing.Callable = ..., digit7Pressed: typing.Callable = ..., digit8Pressed: typing.Callable = ..., digit9Pressed: typing.Callable = ..., downPressed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., enterPressed: typing.Callable = ..., escapePressed: typing.Callable = ..., flipPressed: typing.Callable = ..., focus: bool = ..., focusChanged: typing.Callable = ..., hangupPressed: typing.Callable = ..., isShareable: bool = ..., leftPressed: typing.Callable = ..., menuPressed: typing.Callable = ..., noPressed: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., numberSignPressed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., pressed: typing.Callable = ..., released: typing.Callable = ..., removedFromEntity: typing.Callable = ..., returnPressed: typing.Callable = ..., rightPressed: typing.Callable = ..., selectPressed: typing.Callable = ..., shareableChanged: typing.Callable = ..., sourceDevice: Qt3DInput.QKeyboardDevice = ..., sourceDeviceChanged: typing.Callable = ..., spacePressed: typing.Callable = ..., tabPressed: typing.Callable = ..., upPressed: typing.Callable = ..., volumeDownPressed: typing.Callable = ..., volumeUpPressed: typing.Callable = ..., yesPressed: typing.Callable = ...) -> None: ...
        def focus(self) -> bool: ...
        def setFocus(self, focus: bool) -> None: ...
        def setSourceDevice(self, keyboardDevice: Qt3DInput.QKeyboardDevice) -> None: ...
        def sourceDevice(self) -> Qt3DInput.QKeyboardDevice: ...

    class QLogicalDevice(PySide2.Qt3DCore.Qt3DCore.QComponent):
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., addedToEntity: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QLogicalDevice.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., isShareable: bool = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., removedFromEntity: typing.Callable = ..., shareableChanged: typing.Callable = ...) -> None: ...
        def actions(self) -> typing.List[Qt3DInput.QAction]: ...
        def addAction(self, action: Qt3DInput.QAction) -> None: ...
        def addAxis(self, axis: Qt3DInput.QAxis) -> None: ...
        def axes(self) -> typing.List[Qt3DInput.QAxis]: ...
        def removeAction(self, action: Qt3DInput.QAction) -> None: ...
        def removeAxis(self, axis: Qt3DInput.QAxis) -> None: ...

    class QMouseDevice(Qt3DInput.QAbstractPhysicalDevice):
        class Axis:
            WheelX: typing.ClassVar[Qt3DInput.QMouseDevice.Axis] = ...
            WheelY: typing.ClassVar[Qt3DInput.QMouseDevice.Axis] = ...
            X: typing.ClassVar[Qt3DInput.QMouseDevice.Axis] = ...
            Y: typing.ClassVar[Qt3DInput.QMouseDevice.Axis] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __add__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __mul__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __pos__(self): ...
            def __radd__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __rmul__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __rsub__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __sub__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseDevice.Axis: ...
        WheelX: typing.ClassVar[Qt3DInput.QMouseDevice.Axis] = ...
        WheelY: typing.ClassVar[Qt3DInput.QMouseDevice.Axis] = ...
        X: typing.ClassVar[Qt3DInput.QMouseDevice.Axis] = ...
        Y: typing.ClassVar[Qt3DInput.QMouseDevice.Axis] = ...
        sensitivityChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        updateAxesContinuouslyChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., defaultPropertyTrackingMode: Qt3DInput.QMouseDevice.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., sensitivity: float = ..., sensitivityChanged: typing.Callable = ..., updateAxesContinuously: bool = ..., updateAxesContinuouslyChanged: typing.Callable = ...) -> None: ...
        def axisCount(self) -> int: ...
        def axisIdentifier(self, name: str) -> int: ...
        def axisNames(self) -> typing.List[str]: ...
        def buttonCount(self) -> int: ...
        def buttonIdentifier(self, name: str) -> int: ...
        def buttonNames(self) -> typing.List[str]: ...
        def sensitivity(self) -> float: ...
        def setSensitivity(self, value: float) -> None: ...
        def setUpdateAxesContinuously(self, updateAxesContinuously: bool) -> None: ...
        def updateAxesContinuously(self) -> bool: ...

    class QMouseEvent(PySide2.QtCore.QObject):
        class Buttons:
            BackButton: typing.ClassVar[Qt3DInput.QMouseEvent.Buttons] = ...
            LeftButton: typing.ClassVar[Qt3DInput.QMouseEvent.Buttons] = ...
            MiddleButton: typing.ClassVar[Qt3DInput.QMouseEvent.Buttons] = ...
            NoButton: typing.ClassVar[Qt3DInput.QMouseEvent.Buttons] = ...
            RightButton: typing.ClassVar[Qt3DInput.QMouseEvent.Buttons] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __add__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __mul__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __pos__(self): ...
            def __radd__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __rmul__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __rsub__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __sub__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Buttons: ...

        class Modifiers:
            AltModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
            ControlModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
            KeypadModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
            MetaModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
            NoModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
            ShiftModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __add__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __mul__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __pos__(self): ...
            def __radd__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __rmul__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __rsub__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __sub__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DInput.QMouseEvent.Modifiers: ...
        AltModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
        BackButton: typing.ClassVar[Qt3DInput.QMouseEvent.Buttons] = ...
        ControlModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
        KeypadModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
        LeftButton: typing.ClassVar[Qt3DInput.QMouseEvent.Buttons] = ...
        MetaModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
        MiddleButton: typing.ClassVar[Qt3DInput.QMouseEvent.Buttons] = ...
        NoButton: typing.ClassVar[Qt3DInput.QMouseEvent.Buttons] = ...
        NoModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
        RightButton: typing.ClassVar[Qt3DInput.QMouseEvent.Buttons] = ...
        ShiftModifier: typing.ClassVar[Qt3DInput.QMouseEvent.Modifiers] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def button(self) -> Qt3DInput.QMouseEvent.Buttons: ...
        def buttons(self) -> int: ...
        def isAccepted(self) -> bool: ...
        def modifiers(self) -> Qt3DInput.QMouseEvent.Modifiers: ...
        def setAccepted(self, accepted: bool) -> None: ...
        def type(self) -> PySide2.QtCore.QEvent.Type: ...
        def wasHeld(self) -> bool: ...
        def x(self) -> int: ...
        def y(self) -> int: ...

    class QMouseHandler(PySide2.Qt3DCore.Qt3DCore.QComponent):
        clicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
        containsMouseChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        doubleClicked: typing.ClassVar[PySide2.QtCore.Signal] = ...
        entered: typing.ClassVar[PySide2.QtCore.Signal] = ...
        exited: typing.ClassVar[PySide2.QtCore.Signal] = ...
        positionChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        pressAndHold: typing.ClassVar[PySide2.QtCore.Signal] = ...
        pressed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        released: typing.ClassVar[PySide2.QtCore.Signal] = ...
        sourceDeviceChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        wheel: typing.ClassVar[PySide2.QtCore.Signal] = ...
        def __init__(self, parent: typing.Union[PySide2.Qt3DCore.Qt3DCore.QNode, None] = ..., addedToEntity: typing.Callable = ..., clicked: typing.Callable = ..., containsMouse: bool = ..., containsMouseChanged: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DInput.QMouseHandler.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., doubleClicked: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., entered: typing.Callable = ..., exited: typing.Callable = ..., isShareable: bool = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., positionChanged: typing.Callable = ..., pressAndHold: typing.Callable = ..., pressed: typing.Callable = ..., released: typing.Callable = ..., removedFromEntity: typing.Callable = ..., shareableChanged: typing.Callable = ..., sourceDevice: Qt3DInput.QMouseDevice = ..., sourceDeviceChanged: typing.Callable = ..., wheel: typing.Callable = ...) -> None: ...
        def containsMouse(self) -> bool: ...
        def setContainsMouse(self, contains: bool) -> None: ...
        def setSourceDevice(self, mouseDevice: Qt3DInput.QMouseDevice) -> None: ...
        def sourceDevice(self) -> Qt3DInput.QMouseDevice: ...

    class QWheelEvent(PySide2.QtCore.QObject):
        class Buttons:
            BackButton: typing.ClassVar[Qt3DInput.QWheelEvent.Buttons] = ...
            LeftButton: typing.ClassVar[Qt3DInput.QWheelEvent.Buttons] = ...
            MiddleButton: typing.ClassVar[Qt3DInput.QWheelEvent.Buttons] = ...
            NoButton: typing.ClassVar[Qt3DInput.QWheelEvent.Buttons] = ...
            RightButton: typing.ClassVar[Qt3DInput.QWheelEvent.Buttons] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __add__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __mul__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __pos__(self): ...
            def __radd__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __rmul__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __rsub__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __sub__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Buttons: ...

        class Modifiers:
            AltModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
            ControlModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
            KeypadModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
            MetaModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
            NoModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
            ShiftModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __add__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __mul__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __pos__(self): ...
            def __radd__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __rmul__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __rsub__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __sub__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DInput.QWheelEvent.Modifiers: ...
        AltModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
        BackButton: typing.ClassVar[Qt3DInput.QWheelEvent.Buttons] = ...
        ControlModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
        KeypadModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
        LeftButton: typing.ClassVar[Qt3DInput.QWheelEvent.Buttons] = ...
        MetaModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
        MiddleButton: typing.ClassVar[Qt3DInput.QWheelEvent.Buttons] = ...
        NoButton: typing.ClassVar[Qt3DInput.QWheelEvent.Buttons] = ...
        NoModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
        RightButton: typing.ClassVar[Qt3DInput.QWheelEvent.Buttons] = ...
        ShiftModifier: typing.ClassVar[Qt3DInput.QWheelEvent.Modifiers] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def angleDelta(self) -> PySide2.QtCore.QPoint: ...
        def buttons(self) -> int: ...
        def isAccepted(self) -> bool: ...
        def modifiers(self) -> Qt3DInput.QWheelEvent.Modifiers: ...
        def setAccepted(self, accepted: bool) -> None: ...
        def type(self) -> PySide2.QtCore.QEvent.Type: ...
        def x(self) -> int: ...
        def y(self) -> int: ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
